/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'smiley', 'fr', {
	options: 'Options des émoticones',
	title: 'Insérer un émoticone',
	toolbar: 'Émoticone'
} );
